@@ -1,3 +1,5 @@
+import wtforms.i18n
+from asgi_babel import BabelMiddleware
 from fastapi import APIRouter, FastAPI
 from fastapi.staticfiles import StaticFiles
 
@@ -10,7 +12,7 @@ from fief.apps.auth.routers.user import router as user_router
 from fief.apps.auth.routers.well_known import router as well_known_router
 from fief.middlewares.cors import CORSMiddlewarePath
 from fief.middlewares.csrf import CSRFCookieSetterMiddleware
-from fief.paths import STATIC_DIRECTORY
+from fief.paths import LOCALE_DIRECTORY, STATIC_DIRECTORY
 
 
 def include_routers(router: APIRouter) -> APIRouter:
@@ -38,6 +40,14 @@ app.add_middleware(
     allow_methods=["*"],
     allow_headers=["Authorization", "X-Requested-With"],
 )
+
+app.add_middleware(
+    BabelMiddleware,
+    locales_dirs=[
+        LOCALE_DIRECTORY,
+        wtforms.i18n.messages_path(),
+    ],
+)
 app.include_router(default_tenant_router)
 app.include_router(tenant_router)
 app.mount("/static", StaticFiles(directory=STATIC_DIRECTORY), name="auth:static")
