@@ -1,11 +1,12 @@
 from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
+from babel import Locale
 from pydantic import UUID4
 from sqlalchemy import Boolean, Column, ForeignKey, String
 from sqlalchemy.orm import relationship
 from sqlalchemy.sql.schema import UniqueConstraint
 
-from fief.locale import Translations, get_preferred_translations
+from fief.locale import Translations, get_translations
 from fief.models.base import WorkspaceBase
 from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
 from fief.models.tenant import Tenant
@@ -49,8 +50,8 @@ class User(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
             for user_field_value in self.user_field_values
         )
 
-    def get_preferred_translations(self) -> Translations:
-        return get_preferred_translations([])
+    def get_translations(self) -> Translations:
+        return get_translations(locale=Locale.parse("en_US"))
 
     def get_user_field_value(self, user_field: UserField) -> Optional["UserFieldValue"]:
         for user_field_value in self.user_field_values:
