@@ -3,6 +3,7 @@ import sentry_sdk
 from sentry_sdk.integrations.redis import RedisIntegration
 
 from fief import __version__
+from fief.logger import logger
 from fief.settings import settings
 
 sentry_sdk.init(
@@ -14,4 +15,6 @@ sentry_sdk.init(
 
 from fief import tasks
 
+logger.info("Fief Worker started", version=__version__)
+
 __all__ = ["tasks"]
